@@ -244,7 +244,7 @@ const char *itoa2(long int n)
 }
 
 /*
- * Modify string in place
+ * Modify string in place.
  */
 char *remove_char_from_str(char *str, char c)
 {
@@ -260,7 +260,7 @@ char *remove_char_from_str(char *str, char c)
 }
 
 /*
- * Modify string in place
+ * Modify string in place.
  */
 char *remove_trailing_whitespaces_from_str(char *str)
 {
@@ -273,45 +273,72 @@ char *remove_trailing_whitespaces_from_str(char *str)
 }
 
 /*
- * Very basic xor sym encryption for small strings (up to 511 chars).
- * *** Key must be ascii / if 2 chars match (in str and key) the string is cut ***
- * *** Allow up to 16 simultaneous calls ***
- * Works with ascii strings, probably not otherwise so don't try with
- * exotic things...
+ * Check that str contains only digits (at least one) and whitespaces
+ * (may start and/or end with whitespaces), meaning numerical value is
+ * integer >= 0.
  */
-const char *str_crypt(const char *str, const char *key)
+int str_is_num(const char *str2)
 {
-	/* Array of 16 strings (like for readable_size() - see above) */
-	static char	str2[16][512];
-	static int	count = -1;
-	int		i, j;
+	char	*str, *s;
+	int	i, len;
 
-	count++;
-	count &= 15;
-	for (i = 0, j = 0; i < 511 && str[i] != '\0'; i++) {
-		if (key[j] == '\0')
-			j = 0;
-		str2[count][i] = str[i] ^ key[j++];
+	if (*str2 == '\0')
+		return FALSE;
+	s = str = l_str_new(str2);
+	len = strlen(str);
+	i = 0;
+	while (i < len)
+		if (isspace((int)*s)) {
+			i++;
+			s++;
+		} else
+			break;
+	if (i == len) {
+		l_str_free(str);
+		return FALSE;
 	}
-	str2[count][i] = '\0';
-	return (const char *)str2[count];
+	while (i < len)
+		if (isdigit((int)*s)) {
+			i++;
+			s++;
+		} else
+			break;
+	if (i == len) {
+		l_str_free(str);
+		return TRUE;
+	}
+	while (i < len)
+		if (isspace((int)*s)) {
+			i++;
+			s++;
+		} else
+			break;
+	l_str_free(str);
+	if (i == len)
+		return TRUE;
+	else
+		return FALSE;
 }
 
 /*
- * Very basic crypto hash
+ * Check that str contains only whitespaces or is empty.
  */
-unsigned long str_crypto_hash(const char *str, const char* salt)
+int str_is_blank(const char *str)
 {
-	char		*str2;
-	unsigned long	hash = 0;
-	int		i = 0;
+	int	i = 0, len = strlen(str);
 
-	str2 = (char *)str_crypt(str, salt);
-	while (str2[i] != '\0') {
-		hash += str2[i] * 1024 + (str2[i] + 128) * (32 + i) + str2[i] - 1;
-		i ++;
-	}
-	return hash;
+	if (*str == '\0')
+		return TRUE;
+	while (i < len)
+		if (isspace((int)*str)) {
+			i++;
+			str++;
+		} else
+			break;
+	if (i == len)
+		return TRUE;
+	else
+		return FALSE;
 }
 
 /*
@@ -343,3 +370,47 @@ const char *rnd_str(char mode, int length)
 	str[i] = '\0';
 	return str;
 }
+
+#ifdef LIBETM_EXPERIMENTAL_STUFF
+/*
+ * Very basic xor sym encryption for small strings (up to 511 chars).
+ * *** Key must be ascii / if 2 chars match (in str and key) the string is cut off ***
+ * *** Allow up to 16 simultaneous calls ***
+ * Works with ascii strings, probably not otherwise so don't try with
+ * exotic things...
+ */
+const char *str_crypt(const char *str, const char *key)
+{
+	/* Array of 16 strings (like for readable_size() - see above) */
+	static char	str2[16][512];
+	static int	count = -1;
+	int		i, j;
+
+	count++;
+	count &= 15;
+	for (i = 0, j = 0; i < 511 && str[i] != '\0'; i++) {
+		if (key[j] == '\0')
+			j = 0;
+		str2[count][i] = str[i] ^ key[j++];
+	}
+	str2[count][i] = '\0';
+	return (const char *)str2[count];
+}
+
+/*
+ * Very basic crypto hash.
+ */
+unsigned long str_crypto_hash(const char *str, const char* salt)
+{
+	char		*str2;
+	unsigned long	hash = 0;
+	int		i = 0;
+
+	str2 = (char *)str_crypt(str, salt);
+	while (str2[i] != '\0') {
+		hash += str2[i] * 1024 + (str2[i] + 128) * (32 + i) + str2[i] - 1;
+		i ++;
+	}
+	return hash;
+}
+#endif
