@@ -21,7 +21,7 @@
 
 #define APP_NAME		"Tickr"
 #define APP_CMD			"tickr"
-#define APP_VERSION_NUMBER	"0.6.1"
+#define APP_VERSION_NUMBER	"0.6.2"
 #define WEBSITE_URL		"http://www.newsrssticker.com"
 #define SUPPORT_URL		WEBSITE_URL"/help.php"
 #define DOWNLOAD_URL		WEBSITE_URL"/download.php"
@@ -32,9 +32,10 @@
 #define _GNU_SOURCE
 #define _ISOC99_SOURCE
 
-/*#define WITHOUT_GTK_SPINNER*/		/* For karmic and jaunty (now deprecated) */
+/*#define DOUBLE_LINE_TICKER*/		/* NEW and experimental/unstable */
+
 #define VERBOSE_OUTPUT
-/*#define DEBUG_OUTPUT*/
+/*#define DEBUG_OUTPUT*/		/* Actually never used so far */
 
 /* For info_win_wait(..., timeout) */
 /*#define INFO_WIN_WAIT_POS	GTK_WIN_POS_CENTER*/	/* Same as for info_win() */
@@ -45,6 +46,11 @@
 #define CONNECT_FAIL_MAX	5
 #define CONNECT_FAIL_TIMEOUT	1
 
+/* To avoid confusion.
+ * We must make sure this value doesn't conflict with any other user-defined GTK_RESPONSE_STH
+ * (at the moment, only one enum in tickr_feedpicker.c.) */
+#define GTK_RESPONSE_CANCEL_CLOSE	100	/* Predefined GTK_RESPONSE_ are < 0 */
+
 /* For correctness sake, 'uri' should be used instead of 'url'. */
 
 #include <stdio.h>
@@ -83,7 +89,7 @@
 #endif
 #include <libxml/parser.h>
 #include <libxml/tree.h>
-#include "../libetm-0.4.3/libetm.h"
+#include "../libetm-0.4.4/libetm.h"
 #include "tickr_socket.h"
 #include "tickr_list.h"
 
@@ -104,7 +110,11 @@
 #define N_OPTION_MAX		64	/* Max number of options */
 #define N_URL_MAX		1024	/* Max number of url's */
 #define NFEEDLINKANDOFFSETMAX	256	/* Max number of "open-able" links per feed */
-#define LINK_TAG_CHAR		'^'	/* ascii 5E - char used internally for links, removed from feed text */
+/*#define LINK_TAG_CHAR		'^'*/	/* ascii 5E - char used internally for links, removed from feed text */
+#define LINK_TAG_CHAR		((char)(1))	/* char (ascii 01) used internally for item links, removed from feed text */
+#define ITEM_TITLE_TAG_CHAR	((char)(2))	/* char (ascii 02) used internally for item titles, --- */
+#define ITEM_DES_TAG_CHAR	((char)(3))	/* char (ascii 03) used internally for item descrptions, --- */
+
 #define TMPSTR_SIZE		(2 * 1024 - 1)	/* Used for most tmp strings - must be large enough */
 #ifndef G_OS_WIN32
 # define SEPARATOR_CHAR		'/'
@@ -153,6 +163,7 @@
 #define URL_LIST_FILE		APP_CMD"-url-list"
 #define RESOURCE_DUMP		APP_CMD"-resrc-dump"
 #define XML_DUMP		APP_CMD"-xml-dump"
+#define XML_DUMP_EXTRA		APP_CMD"-xml-dump-extra"
 #define TMP1			"tmp1"
 #define TMP2			"tmp2"
 #ifndef G_OS_WIN32
@@ -229,12 +240,13 @@
 #define CLOCK			'n'
 #define CFONTNAME		FONTNAME
 #define CFONTSIZE		"12"
-#define CFGCOLOR		FGCOLOR
+#define CFGCOLOR		"#aeaeaeff"	/* White but darker than text*/
 #define CBGCOLOR		BGCOLOR
 #define DISABLEPOPUPS		'n'
 #define PAUSEONMOUSEOVER	'y'
 #define DISABLELEFTCLICK	'n'
 #define MOUSEWHEELSCROLL	's'
+#define ENABLEFEEDORDERING	'n'
 #define USEAUTHENTICATION	'n'
 #define USER			""
 #define USEPROXY		'n'
@@ -309,7 +321,8 @@ typedef struct {
 	cairo_surface_t	*c_surf;			/* Cairo image surface onto which text is rendered */
 	gint 		surf_width, surf_height;	/* Cairo image surface dimensions */
 	char		active_link[FILE_NAME_MAXLEN + 1];
-	/* These flags are checked by callback */
+	int		mouse_x_in_drwa;
+	/* These flags are checked mainly by shift2left_callback() */
 	gboolean	suspend_rq;			/* Request for doing nothing */
 	gboolean	compute_rq;			/* Request for (re)computing everything (surface and win) */
 	gboolean	reload_rq;			/* Request for (re)loading resource */
@@ -333,8 +346,11 @@ typedef struct {
 	char		feed_title[FEED_TITLE_MAXLEN + 1];
 	char		resrc_dump[FILE_NAME_MAXLEN + 1];	/* Downloaded file/resource */
 	char		xml_dump[FILE_NAME_MAXLEN + 1];
-	FILE		*fp;				/* File to be read (from xmldump) after some processing, */
+	FILE		*fp;				/* File to be read (from xmldump) after some processing */
 	FeedLinkAndOffset link_and_offset[NFEEDLINKANDOFFSETMAX];
+	char		xml_dump_extra[FILE_NAME_MAXLEN + 1];
+	FILE		*fp_extra;			/* File with extra info: item titles (or des) generated
+							 * when ticker displays only des (or titles) */
 	int		rss_ttl;
 } Resource;
 
@@ -417,6 +433,7 @@ typedef struct {
 	char		pause_on_mouseover;
 	char		disable_leftclick;
 	char		mouse_wheel_scroll;	/* Apply to s (speed) / f (feed) / n (none) */
+	char		enable_feed_ordering;
 /* Do we need both these auth/proxy structs and auth/proxy params? redundant... */
 	char		use_authentication;
 	char		user[USER_MAXLEN + 1];
@@ -464,6 +481,8 @@ typedef enum {
 	RENDER_CREATE_CAIRO_IMAGE_SURFACE_ERROR,
 	RENDER_OTHER_ERROR,
 
+	SHIFT2LEFT_NULL_CAIRO_IMAGE_SURFACE,
+
 	FLIST_ERROR,
 	LOAD_URL_LIST_ERROR,
 	LOAD_URL_LIST_EMPTY_LIST,
@@ -512,7 +531,9 @@ void		set_feed_selection(FList *);
 Params		*get_params();
 int		get_instance_id();
 void		check_main_win_always_on_top();
-gboolean	params_have_been_changed(Params *, int);
+char		*get_feed_extra_info(int);
+/*gboolean	params_have_been_changed(Params *, int);*/
+gboolean	win_params_have_been_changed(Params *, int);
 gint		update_everything();
 
 /* tickr_resource.c */
@@ -523,13 +544,16 @@ void		last_feed();
 gboolean	previous_feed();
 gboolean	next_feed();
 int		load_resource(Resource *, FList *);
-int		format_resource(Resource *);
+int		format_resource(Resource *, const char *);
 void		set_tickr_icon_to_dialog(GtkWindow *);
 FILE		*open_new_datafile_with_name(const char *, const char *);
 char		*get_datafile_full_name_from_name(const char *);
 char		*get_imagefile_full_name_from_name(const char *);
 char		*get_datadir_full_path();
 char		*usr_home_dir();
+#ifdef G_OS_WIN32
+const char	*get_appdata_dir_utf8();
+#endif
 
 /* tickr_render.c */
 cairo_surface_t *render_stream_to_surface(FILE *, FeedLinkAndOffset *, const Params *, int *);
@@ -558,21 +582,21 @@ gint		get_clock_width(const Params *);
 
 /* tickr_feedparser.c */
 int		get_feed(Resource *, const Params *);
-int		parse_rss20_xml_file(FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
+int		parse_rss20_xml_file(FILE *, FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
 			const Params *);
-/*int		parse_rss10_xml_file(FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
+/*int		parse_rss10_xml_file(FILE *, FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
 			const Params *);*/
-int		parse_atom_xml_file(FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
+int		parse_atom_xml_file(FILE *, FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
 			const Params *);
 void		get_rss20_selected_elements1(xmlNode *, xmlDoc *);
-void		get_rss20_selected_elements2(xmlNode *, xmlDoc *,\
-			FILE *, FeedLinkAndOffset *link_and_offset, const Params *);
+void		get_rss20_selected_elements2(xmlNode *, xmlDoc *, FILE *, FILE *,\
+			FeedLinkAndOffset *link_and_offset, const Params *);
 /*void		get_rss10_selected_elements1(xmlNode *, xmlDoc *);
-void		get_rss10_selected_elements2(xmlNode *, xmlDoc *,\
-			FILE *, FeedLinkAndOffset *link_and_offset, const Params *);*/
+void		get_rss10_selected_elements2(xmlNode *, xmlDoc *, FILE *, FILE *,\
+*			FeedLinkAndOffset *link_and_offset, const Params *);*/
 void		get_atom_selected_elements1(xmlNode *, xmlDoc *);
-void		get_atom_selected_elements2(xmlNode *, xmlDoc *,\
-			FILE *, FeedLinkAndOffset *link_and_offset, const Params *);
+void		get_atom_selected_elements2(xmlNode *, xmlDoc *, FILE *, FILE *,\
+			FeedLinkAndOffset *link_and_offset, const Params *);
 int		get_feed_info(const char *, char *, char *, char *);
 void		get_xml_first_element(xmlNode *, xmlDoc *, char *, char *, int);
 
