@@ -30,7 +30,7 @@ static int	counter;
 
 /*
  * Look for url and, if valid, parse it then dump result into
- * '<user_home_dir>/'TICKR_DIR_NAME/XMLDUMP'.
+ * '<user_home_dir>/'TICKR_DIR_NAME/XML_DUMP'.
  * If url isn't valid, only set error code and return.
  */
 int get_feed(Resource *resrc, const Params *prm)
@@ -46,18 +46,25 @@ int get_feed(Resource *resrc, const Params *prm)
 	get_ticker_env()->suspend_rq = TRUE;
 
 	resrc->rss_ttl = prm->rss_refresh;
+
 	str_n_cpy(resrc->xml_dump, get_datafile_full_name_from_name(XML_DUMP), FILE_NAME_MAXLEN);
 	if (resrc->fp != NULL)
 		fclose(resrc->fp);
 	resrc->fp = open_new_datafile_with_name(XML_DUMP, "wb");
+
+	str_n_cpy(resrc->xml_dump_extra, get_datafile_full_name_from_name(XML_DUMP_EXTRA), FILE_NAME_MAXLEN);
+	if (resrc->fp_extra != NULL)
+		fclose(resrc->fp_extra);
+	resrc->fp_extra = open_new_datafile_with_name(XML_DUMP_EXTRA, "wb");
+
 	str_n_cpy(file_name, get_datafile_full_name_from_name(RESOURCE_DUMP), FILE_NAME_MAXLEN);
 
 	/* We replace resrc->id with modified url, file_name = downloaded resource */
-	if ((exit_status = fetch_resource((const char *)resrc->id, (const char *)file_name, url)) == OK)
+	if ((exit_status = fetch_resource((const char *)resrc->id, (const char *)file_name, url)) == OK) {
 #ifdef VERBOSE_OUTPUT
 		fprintf(STD_OUT, "Resource fetched: %s\n", (const char *)resrc->id);
 #endif
-	else if (exit_status == FEED_FORMAT_ERROR) {
+	} else if (exit_status == FEED_FORMAT_ERROR) {
 		warning(get_ticker_env()->selection_mode == MULTIPLE,  2,
 			"Feed format error (RSS2.0/Atom) in: ", resrc->id);
 		return FEED_FORMAT_ERROR;
@@ -69,8 +76,8 @@ int get_feed(Resource *resrc, const Params *prm)
 		return FEED_DOWNLOAD_ERROR;
 	}
 
-	/* TODO: Fix html named entities issue ? I mean, is it a Tickr bug or ?
-	 * -> libxml2 read html *numeric* entities, not *named* ones (with a few exceptions)
+	/* Libxml2 html named entities issue (not a Tickr bug):
+	 * Libxml2 read html *numeric* entities, not *named* ones (with a few exceptions)
 	 * so, for instance, &#160; is ok but &nbsp; is not. */
 
 	/* We use file_name instead of resrc->id */
@@ -89,7 +96,7 @@ int get_feed(Resource *resrc, const Params *prm)
 	}
 	resrc->format = RSS_2_0;
 	/* We use file_name instead of resrc->id */
-	if ((exit_status = parse_rss20_xml_file(resrc->fp, file_name,
+	if ((exit_status = parse_rss20_xml_file(resrc->fp, resrc->fp_extra, file_name,
 			resrc->link_and_offset, prm)) == RSS_NO_ITEM_ELEMENT) {
 		resrc->format = RSS_ATOM;
 		for (i = 0; i < NFEEDLINKANDOFFSETMAX; i++) {
@@ -97,7 +104,7 @@ int get_feed(Resource *resrc, const Params *prm)
 			(resrc->link_and_offset[i].url)[0] = '\0';
 		}
 		/* We use file_name instead of resrc->id */
-		if ((exit_status = parse_atom_xml_file(resrc->fp, file_name,
+		if ((exit_status = parse_atom_xml_file(resrc->fp, resrc->fp_extra, file_name,
 				resrc->link_and_offset, prm)) == ATOM_NO_ENTRY_ELEMENT)
 			warning(get_ticker_env()->selection_mode == MULTIPLE, 3,
 				"No 'Item' or 'Entry' element found in: ", resrc->id,
@@ -110,6 +117,8 @@ int get_feed(Resource *resrc, const Params *prm)
 	}
 	fclose(resrc->fp);
 	resrc->fp = open_new_datafile_with_name(XML_DUMP, "rb");
+	fclose(resrc->fp_extra);
+	resrc->fp_extra = open_new_datafile_with_name(XML_DUMP_EXTRA, "rb");
 	get_ticker_env()->suspend_rq = suspend_rq_bak;
 	return OK;
 }
@@ -117,7 +126,8 @@ int get_feed(Resource *resrc, const Params *prm)
 /*
  * Must be utf-8 encoded
  */
-int parse_rss20_xml_file(FILE *fp, const char* file_name, FeedLinkAndOffset *link_and_offset, const Params *prm)
+int parse_rss20_xml_file(FILE *fp, FILE *fp_extra, const char* file_name,\
+	FeedLinkAndOffset *link_and_offset, const Params *prm)
 {
 	xmlDoc	*doc;
 	xmlNode	*root_element;
@@ -144,7 +154,7 @@ int parse_rss20_xml_file(FILE *fp, const char* file_name, FeedLinkAndOffset *lin
 
 	get_rss20_selected_elements1(root_element, doc);
 	if (item_element != NULL)
-		get_rss20_selected_elements2(item_element, doc, fp, link_and_offset, prm);
+		get_rss20_selected_elements2(item_element, doc, fp, fp_extra, link_and_offset, prm);
 	else {
 		xmlFreeDoc(doc);
 		return RSS_NO_ITEM_ELEMENT;
@@ -159,7 +169,8 @@ int parse_rss20_xml_file(FILE *fp, const char* file_name, FeedLinkAndOffset *lin
 /*
  * Must be utf-8 encoded
  */
-int parse_atom_xml_file(FILE *fp, const char* file_name, FeedLinkAndOffset *link_and_offset, const Params *prm)
+int parse_atom_xml_file(FILE *fp, FILE *fp_extra, const char* file_name,\
+	FeedLinkAndOffset *link_and_offset, const Params *prm)
 {
 	xmlDoc	*doc;
 	xmlNode	*root_element;
@@ -186,7 +197,7 @@ int parse_atom_xml_file(FILE *fp, const char* file_name, FeedLinkAndOffset *link
 
 	get_atom_selected_elements1(root_element, doc);
 	if (entry_element != NULL)
-		get_atom_selected_elements2(entry_element, doc, fp, link_and_offset, prm);
+		get_atom_selected_elements2(entry_element, doc, fp, fp_extra, link_and_offset, prm);
 	else {
 		xmlFreeDoc(doc);
 		return ATOM_NO_ENTRY_ELEMENT;
@@ -225,8 +236,8 @@ void get_rss20_selected_elements1(xmlNode *some_element, xmlDoc *doc)
 	}
 }
 
-void get_rss20_selected_elements2(xmlNode *some_element, xmlDoc *doc,
-		FILE *fp, FeedLinkAndOffset *link_and_offset, const Params *prm)
+void get_rss20_selected_elements2(xmlNode *some_element, xmlDoc *doc, FILE *fp, FILE *fp_extra,\
+	FeedLinkAndOffset *link_and_offset, const Params *prm)
 {
 	xmlNode	*cur_node, *cur_node_bak;
 	xmlChar	*str;
@@ -236,18 +247,26 @@ void get_rss20_selected_elements2(xmlNode *some_element, xmlDoc *doc,
 			cur_node_bak = cur_node;
 			cur_node = cur_node->children;
 			for (; cur_node != NULL; cur_node = cur_node->next) {
-				if (prm->item_title == 'y' && xmlStrcmp(cur_node->name, (const xmlChar *)"title") == 0) {
+				if (xmlStrcmp(cur_node->name, (const xmlChar *)"title") == 0) {
 					if ((str = xmlNodeListGetString(doc, cur_node->children, 1)) != NULL) {
 						/* We remove any LINK_TAG_CHAR from str because it will be used in "link tag" */
 						remove_char_from_str((char *)str, LINK_TAG_CHAR);
-						fprintf(fp, "%s%s\n", str, prm->item_title_delimiter);
+						remove_char_from_str((char *)str, ITEM_TITLE_TAG_CHAR);
+						if (prm->item_title == 'y')
+							fprintf(fp, "%s%s\n", str, prm->item_title_delimiter);
+						else if (prm->item_description == 'y')
+							fprintf(fp_extra, "%c%03d%s\n", ITEM_TITLE_TAG_CHAR, n, str);
 						xmlFree(str);
 					}
-				} else if (prm->item_description == 'y' && xmlStrcmp(cur_node->name, (const xmlChar *)"description") == 0) {
+				} else if (xmlStrcmp(cur_node->name, (const xmlChar *)"description") == 0) {
 					if ((str = xmlNodeListGetString(doc, cur_node->children, 1)) != NULL) {
 						/* We remove any LINK_TAG_CHAR from str because it will be used in "link tag" */
 						remove_char_from_str((char *)str, LINK_TAG_CHAR);
-						fprintf(fp, "%s%s\n", str, prm->item_description_delimiter);
+						remove_char_from_str((char *)str, ITEM_DES_TAG_CHAR);
+						if (prm->item_description == 'y')
+							fprintf(fp, "%s%s\n", str, prm->item_description_delimiter);
+						else if (prm->item_title == 'y')
+							fprintf(fp_extra, "%c%03d%s\n", ITEM_DES_TAG_CHAR, n, str);
 						xmlFree(str);
 					}
 				}
@@ -301,8 +320,8 @@ void get_atom_selected_elements1(xmlNode *some_element, xmlDoc *doc)
 	}
 }
 
-void get_atom_selected_elements2(xmlNode *some_element, xmlDoc *doc,
-		FILE *fp, FeedLinkAndOffset *link_and_offset, const Params *prm)
+void get_atom_selected_elements2(xmlNode *some_element, xmlDoc *doc, FILE *fp, FILE *fp_extra,\
+		FeedLinkAndOffset *link_and_offset, const Params *prm)
 {
 	xmlNode	*cur_node, *cur_node_bak;
 	xmlChar	*str;
@@ -312,18 +331,26 @@ void get_atom_selected_elements2(xmlNode *some_element, xmlDoc *doc,
 			cur_node_bak = cur_node;
 			cur_node = cur_node->children;
 			for (; cur_node != NULL; cur_node = cur_node->next) {
-				if (prm->item_title == 'y' && xmlStrcmp(cur_node->name, (const xmlChar *)"title") == 0) {
+				if (xmlStrcmp(cur_node->name, (const xmlChar *)"title") == 0) {
 					if ((str = xmlNodeListGetString(doc, cur_node->children, 1)) != NULL) {
 						/* We remove any LINK_TAG_CHAR from str because it will be used in "link tag" */
 						remove_char_from_str((char *)str, LINK_TAG_CHAR);
-						fprintf(fp, "%s%s\n", str, prm->item_title_delimiter);
+						remove_char_from_str((char *)str, ITEM_TITLE_TAG_CHAR);
+						if (prm->item_title == 'y')
+							fprintf(fp, "%s%s\n", str, prm->item_title_delimiter);
+						else if (prm->item_description == 'y')
+							fprintf(fp_extra, "%c%03d%s\n", ITEM_TITLE_TAG_CHAR, n, str);
 						xmlFree(str);
 					}
-				} else if (prm->item_description == 'y' && xmlStrcmp(cur_node->name, (const xmlChar *)"summary") == 0) {
+				} else if (xmlStrcmp(cur_node->name, (const xmlChar *)"description") == 0) {
 					if ((str = xmlNodeListGetString(doc, cur_node->children, 1)) != NULL) {
 						/* We remove any LINK_TAG_CHAR from str because it will be used in "link tag" */
 						remove_char_from_str((char *)str, LINK_TAG_CHAR);
-						fprintf(fp, "%s%s\n", str, prm->item_description_delimiter);
+						remove_char_from_str((char *)str, ITEM_DES_TAG_CHAR);
+						if (prm->item_description == 'y')
+							fprintf(fp, "%s%s\n", str, prm->item_description_delimiter);
+						else if (prm->item_title == 'y')
+							fprintf(fp_extra, "%c%03d%s\n", ITEM_DES_TAG_CHAR, n, str);
 						xmlFree(str);
 					}
 				}
