@@ -32,7 +32,6 @@ static int		shift_counter = 0;
 static GtkWidget	*popup_menu;
 static GtkAccelGroup	*popup_menu_accel_group;
 static int		popup_menu_accel_group_attached;
-static int		position_x_in_drwa;
 static GtkWidget	*main_hbox, *vbox_ticker, *vbox_clock;
 static int		speed_up_flag = FALSE;
 static int		speed_down_flag = FALSE;
@@ -57,8 +56,8 @@ static int		speed_down_flag = FALSE;
 	get_params()->disable_popups = disable_popups_bak;\
 	env->suspend_rq = suspend_rq_bak;
 
-/* Replace USE_GUI macro which has been there and ***unused*** for ages
- * and breaks compile. */
+/* IF_UI_ALLOWED now replace USE_GUI compile macro which has been there
+ * and ***unused*** for ages and breaks compile. Plus it's a runtime variable */
 #define IF_UI_ALLOWED	if (!no_ui)
 
 /* Prototypes for a few static funcs */
@@ -311,7 +310,7 @@ static void show_resource_info()
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			NULL);
 
-	close_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+	close_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL_CLOSE);
 	close_but = close_but;	/* To get rid of one stupid compiler warning */
 
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
@@ -369,7 +368,7 @@ static void show_resource_info()
 	}
 
 	gtk_widget_show_all(dialog);
-	while (gtk_dialog_run(GTK_DIALOG(dialog)) != GTK_RESPONSE_CLOSE);
+	while (gtk_dialog_run(GTK_DIALOG(dialog)) != GTK_RESPONSE_CANCEL_CLOSE);
 
 	gtk_widget_destroy(dialog);
 	check_main_win_always_on_top();
@@ -423,27 +422,31 @@ static void easily_link_with_browser()
 }
 #endif
 
-static int get_visible_link()
+/* If link found, copy it into env->active_link and return rank (starting at 1),
+ * otherwise, return -1 (with link = "") */
+static int get_visible_link_and_rank(int position_x_in_drwa)
 {
 	int	i, location_on_surface;
 
-	location_on_surface = shift_counter * prm->shift_size + position_x_in_drwa;
-	for (i = 0; i < NFEEDLINKANDOFFSETMAX; i++) {
-		if (resrc->link_and_offset[i].offset_in_surface > location_on_surface) {
-			str_n_cpy(env->active_link, resrc->link_and_offset[i].url, FILE_NAME_MAXLEN);
-			return TRUE;
+	if (position_x_in_drwa > -1) {
+		location_on_surface = shift_counter * prm->shift_size + position_x_in_drwa;
+		for (i = 0; i < NFEEDLINKANDOFFSETMAX; i++) {
+			if (resrc->link_and_offset[i].offset_in_surface > location_on_surface) {
+				str_n_cpy(env->active_link, resrc->link_and_offset[i].url, FILE_NAME_MAXLEN);
+				return i;
+			}
 		}
 	}
 	env->active_link[0] = '\0';
-	return FALSE;
+	return -1;
 }
 
 static void open_link()
 {
 	char		tmp1[FILE_NAME_MAXLEN + 1], tmp2[FILE_NAME_MAXLEN + 1];
-#ifdef G_OS_WIN32
+/*#ifdef G_OS_WIN32
 	char		*tmp;
-#endif
+#endif*/
 	char		*argv[32];	/* Up to 32 - 3 (prog name, url, NULL) args */
 	GPid		pid;
 	GError		*error = NULL;
@@ -465,19 +468,13 @@ static void open_link()
 #endif
 	}
 
-	if (env->active_link [0] == '\0') {
+	if (env->active_link[0] == '\0') {
 		warning(FALSE, 1, "No link found");
 		return;
 	}
 
 	fprintf(STD_OUT, "Spawning: %s %s %s\n", prm->open_link_cmd, prm->open_link_args, env->active_link);
-#ifndef G_OS_WIN32
 	str_n_cpy(tmp1, prm->open_link_cmd, FILE_NAME_MAXLEN);
-#else
-	tmp = g_win32_locale_filename_from_utf8(prm->open_link_cmd);
-	str_n_cpy(tmp1, tmp, FILE_NAME_MAXLEN);
-	g_free(tmp);
-#endif
 	str_n_cpy(tmp2, prm->open_link_args, FILE_NAME_MAXLEN);
 	argv[0] = tmp1;
 	for (i = 0, j = 1; tmp2[i] != '\0' && j < 32 + 1 - 3; j++) {
@@ -505,20 +502,27 @@ static void open_link()
 
 static void open_link2()
 {
-	position_x_in_drwa = env->drwa_width / 2;
-	get_visible_link();
+	get_visible_link_and_rank(env->drwa_width / 2);
 	open_link();
 }
 
+/* Continuously get mouse x position inside drawing area.
+ * Do nothing if outside, so must be used only by mouse-over-drawing-area /
+ * click-on-drawing-area funcs. */
+static gint track_mouse_position_x(GtkWidget *widget, GdkEventMotion *event)
+{
+	widget = widget;
+	if (event->type == GDK_MOTION_NOTIFY)	/* Means mouse has moved inside widget  */
+		env->mouse_x_in_drwa = (int)(event->x);
+	return FALSE;
+}
+
 static gint left_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event_but)
 {
 	widget = widget;
-	if (prm->disable_leftclick == 'y')
-		return FALSE;
-	if (event_but->type == GDK_BUTTON_PRESS && event_but->button == 1) {	/* 1 = mouse left button */
-		/* Get pointer x location on drawing_area */
-		position_x_in_drwa = event_but->x;
-		get_visible_link();
+	if (prm->disable_leftclick != 'y' && event_but->type == GDK_BUTTON_PRESS &&\
+			event_but->button == 1) {	/* 1 = mouse left button */
+		get_visible_link_and_rank(env->mouse_x_in_drwa);
 		open_link();
 		return TRUE;
 	} else
@@ -536,7 +540,7 @@ static gint right_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event
 		return FALSE;
 }
 
-static const char *get_win_title_tooltip_text()
+static const char *get_win_title_text()
 {
 	static char	tmp1[2][256 + 64], tmp2[2][64];
 	static int	i = -1;
@@ -552,9 +556,75 @@ static const char *get_win_title_tooltip_text()
 	else
 		str_n_cpy(tmp1[i], "No resource", 256);
 	snprintf(tmp2[i], 64, "  |  %s-%s", APP_NAME, APP_VERSION_NUMBER);
+	/* which is better?
+	snprintf(tmp2[i], 64, "  |  %s", APP_NAME);*/
 	return (const char *)str_n_cat(tmp1[i], tmp2[i], 63);
 }
 
+char *get_feed_extra_info(int rank)
+{
+	FILE		*fp;
+	char		*str1, tmp[4];
+	size_t		str1_size = 8 * 1024;
+	static char	*str2 = NULL;
+	int		tag_found = FALSE;
+
+	if (str2 != NULL)
+		l_str_free(str2);
+	str2 = l_str_new("");
+	str2[0] = '\0';
+	if (rank == -1)
+		return str2;
+	if ((fp = g_fopen(resrc->xml_dump_extra, "rb")) != NULL) {
+		str1 = malloc2(str1_size * sizeof(char));
+#ifndef G_OS_WIN32
+		while (getline(&str1, &str1_size, fp) != -1) {
+#else
+		while (fgets(str1, str1_size, fp) != NULL) {
+#endif
+			if (str1[0] == ITEM_TITLE_TAG_CHAR || str1[0] == ITEM_DES_TAG_CHAR) {
+				if (tag_found)
+					break;
+				if (rank == atoi(str_n_cpy(tmp, str1 + 1, 3))) {
+					tag_found = TRUE;
+					str2 = l_str_cat(str2, str1 + 4);
+				}
+			} else if (tag_found)
+				str2 = l_str_cat(str2, str1);
+		}
+		free2(str1);
+		fclose(fp);
+	}
+	remove_trailing_whitespaces_from_str(str2);
+	return str2;
+}
+
+static const char *get_ticker_tooltip_text(int rank)
+{
+	static char	*tooltip_text = NULL;
+	/*gboolean	feed_extra_info = FALSE;*/
+
+	if (tooltip_text != NULL) {
+		l_str_free(tooltip_text);
+		tooltip_text = NULL;
+	}
+	if ((prm->item_title == 'y' && prm->item_description == 'n') ||\
+			(prm->item_title == 'n' && prm->item_description == 'y')) {
+		tooltip_text = l_str_new(get_feed_extra_info(rank));
+		if (tooltip_text[0] != '\0')
+			/*feed_extra_info = TRUE;
+		if (feed_extra_info)*/
+			tooltip_text = l_str_cat(tooltip_text, "\n\n");
+			/* which is better?
+			tooltip_text = l_str_cat(tooltip_text, "\n\n[ ");*/
+		tooltip_text = l_str_cat(tooltip_text, get_win_title_text());
+		/*if (feed_extra_info)
+			tooltip_text = l_str_cat(tooltip_text, " ]");*/
+		return tooltip_text;
+	} else
+		return get_win_title_text();
+}
+
 /* Pause ticker when mouse pointer is over (opened) popup menu. */
 static gint mouse_over_opened_popup_menu(GtkWidget *widget, GdkEvent *event)
 {
@@ -571,19 +641,26 @@ static gint mouse_over_opened_popup_menu(GtkWidget *widget, GdkEvent *event)
 /* Pause ticker on mouseover. */
 static gint mouse_over_drawing_area(GtkWidget *widget, GdkEvent *event)
 {
+	int	rank;
+
 	widget = widget;
 	if (event->type == GDK_ENTER_NOTIFY || event->type == GDK_LEAVE_NOTIFY) {
 		if (prm->pause_on_mouseover == 'y') {
 			if (event->type == GDK_ENTER_NOTIFY)
 				env->suspend_rq = TRUE;
-			else if (event->type == GDK_LEAVE_NOTIFY)
+			else /* USELESS: if (event->type == GDK_LEAVE_NOTIFY)*/
 				env->suspend_rq = FALSE;
 		}
-		gtk_widget_set_tooltip_text(widget, get_win_title_tooltip_text());
-		gtk_tooltip_trigger_tooltip_query(gdk_display_get_default());
-		return TRUE;
-	} else
-		return FALSE;
+		if (event->type == GDK_ENTER_NOTIFY) {
+			while (gdk_events_pending())	/* So that "motion-notify-event" is processed now */
+				gtk_main_iteration();
+			rank = get_visible_link_and_rank(env->mouse_x_in_drwa);
+			gtk_widget_set_tooltip_text(widget, get_ticker_tooltip_text(rank));
+			gtk_tooltip_trigger_tooltip_query(gdk_display_get_default());
+			return TRUE;
+		}
+	}
+	return FALSE;
 }
 
 static gint mouse_wheel_scroll_on_drawing_area(GtkWidget *widget, GdkEvent *event)
@@ -594,7 +671,7 @@ static gint mouse_wheel_scroll_on_drawing_area(GtkWidget *widget, GdkEvent *even
 	if (event->type == GDK_SCROLL) {
 		mouse_wheel_scroll = prm->mouse_wheel_scroll;
 		if (event->scroll.state & GDK_CONTROL_MASK) {
-			/* if ctrl pressed, invert mouse_wheel_scroll values */
+			/* If ctrl pressed, invert mouse_wheel_scroll values */
 			if (mouse_wheel_scroll == 's')
 				mouse_wheel_scroll = 'f';
 			else if (mouse_wheel_scroll == 'f')
@@ -684,16 +761,16 @@ static GtkItemFactoryEntry popup_menu_item[] = {
 	{"/Control/sep",	NULL, NULL, 0, "<Separator>", NULL},
 
 	{"/Control/First Feed",	"<control>", first_feed2, 0, "<StockItem>",
-				(gconstpointer)GTK_STOCK_GOTO_FIRST/*GTK_STOCK_MEDIA_PREVIOUS*/},
+				(gconstpointer)GTK_STOCK_GOTO_FIRST},
 
 	{"/Control/Previous Feed", "<control>", previous_feed2, 0,  "<StockItem>",
-				(gconstpointer)GTK_STOCK_GO_BACK/*GTK_STOCK_MEDIA_REWIND*/},
+				(gconstpointer)GTK_STOCK_GO_BACK},
 
 	{"/Control/Next Feed",	"<control>", next_feed2, 0, "<StockItem>",
-				(gconstpointer)GTK_STOCK_GO_FORWARD/*GTK_STOCK_MEDIA_FORWARD*/},
+				(gconstpointer)GTK_STOCK_GO_FORWARD},
 
 	{"/Control/Last Feed",	"<control>", last_feed2, 0, "<StockItem>",
-				(gconstpointer)GTK_STOCK_GOTO_LAST/*GTK_STOCK_MEDIA_NEXT*/},
+				(gconstpointer)GTK_STOCK_GOTO_LAST},
 
 	{"/Control/sep",	NULL, NULL, 0, "<Separator>", NULL},
 
@@ -740,25 +817,17 @@ static gint update_win_dims()
 	gtk_window_resize(GTK_WINDOW(env->win), env->drwa_width + env->drwa_clock_width, env->drwa_height);
 
 	gtk_window_unmaximize(GTK_WINDOW(env->win));
-
-	/* This is to prevent win from becoming 'unshowable' */
-	if (prm->icon_in_taskbar == 'n')
-		gtk_window_deiconify(GTK_WINDOW(env->win));
-	/*
-	 * Not about win dims but this must be checked too
-	 * (is there a better place?)
-	 */
-	check_main_win_always_on_top();
 	return TRUE;
 }
 
+/* Not used anymore
 gboolean params_have_been_changed(Params *new_prm, int n_required_runs)
 {
 	static Params	prm_bak;
 	static int	initial_runs = 0;
 
 	if (initial_runs < n_required_runs) {
-		/* 'fake params changes' are required at program startup */
+		// 'fake params changes' are required at program startup
 		initial_runs++;
 		memcpy((void *)&prm_bak, (const void *)new_prm, sizeof(Params));
 		return TRUE;
@@ -767,10 +836,51 @@ gboolean params_have_been_changed(Params *new_prm, int n_required_runs)
 		return TRUE;
 	} else
 		return FALSE;
+}*/
+
+gboolean win_params_have_been_changed(Params *new_prm, int n_required_runs)
+{
+	static Params	prm_bak0;
+	Params		*prm_bak = &prm_bak0;
+	static int	initial_runs = 0;
+	gboolean	changes = FALSE;
+
+	if (initial_runs < n_required_runs) {
+		/* 'fake params changes' are required at program startup */
+		initial_runs++;
+		memcpy((void *)prm_bak, (const void *)new_prm, sizeof(Params));
+		return TRUE;
+	} else if (strcmp(new_prm->font_n_s, prm_bak->font_n_s) != 0)
+		changes = TRUE;
+	else if (new_prm->win_x != prm_bak->win_x)
+		changes = TRUE;
+	else if (new_prm->win_y != prm_bak->win_y)
+		changes = TRUE;
+	else if (new_prm->win_w != prm_bak->win_w)
+		changes = TRUE;
+	else if (new_prm->win_h != prm_bak->win_h)
+		changes = TRUE;
+	else if (new_prm->windec != prm_bak->windec)
+		changes = TRUE;
+	else if (new_prm->always_on_top != prm_bak->always_on_top)
+		changes = TRUE;
+	else if (new_prm->icon_in_taskbar != prm_bak->icon_in_taskbar)
+		changes = TRUE;
+	else if (new_prm->win_sticky != prm_bak->win_sticky)
+		changes = TRUE;
+	else if (new_prm->clock != prm_bak->clock)
+		changes = TRUE;
+	else if (strcmp(new_prm->clock_font_n_s, prm_bak->clock_font_n_s) != 0)
+		changes = TRUE;
+	if (changes == TRUE) {
+		memcpy((void *)prm_bak, (const void *)new_prm, sizeof(Params));
+		return TRUE;
+	} else
+		return FALSE;
 }
 
 /*
- * Create new or next cairo image surface & compute stuff to redraw window.
+ * Create new or next cairo image surface and compute stuff to redraw window.
  */
 static int compute_surface_and_win()
 {
@@ -779,9 +889,6 @@ static int compute_surface_and_win()
 	gint		height1, height2;
 	int		size, render_exit_status, i;
 
-	gtk_window_set_keep_above(GTK_WINDOW(env->win), FALSE);
-	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(env->win), FALSE);
-	gtk_window_unstick(GTK_WINDOW(env->win));
 	/*
 	 * Compute font size from requested height if > 0
 	 */
@@ -831,6 +938,10 @@ static int compute_surface_and_win()
 			resrc->link_and_offset[i].url[0] = '\0';
 			resrc->link_and_offset[i].offset_in_surface = 0;
 		}
+		if(resrc->fp_extra != NULL) {
+			fclose(resrc->fp_extra);
+			resrc->fp_extra = NULL;
+		}
 	}
 	/*
 	 * Create cairo image surface of rendered text (one long single line)
@@ -867,50 +978,56 @@ static int compute_surface_and_win()
 	env->surf_height = cairo_image_surface_get_height(env->c_surf);
 	env->drwa_height = (MIN(env->surf_height, env->screen_h));
 	/*
-	 * Window layout stuff
+	 * Window layout stuff - 'TICKR STEAL FOCUS' BUG SOMEWERE
 	 */
 	/* Win title */
-	gtk_window_set_title(GTK_WINDOW(env->win), get_win_title_tooltip_text());
-	/* Move win */
-	gtk_window_move(GTK_WINDOW(env->win), prm->win_x, prm->win_y);
-	/* Win decoration */
-	if (prm->windec == 'y') {
-		gtk_window_set_decorated(GTK_WINDOW(env->win), TRUE);
-		if (!popup_menu_accel_group_attached) {
-			gtk_window_add_accel_group(GTK_WINDOW(env->win), popup_menu_accel_group);
-			popup_menu_accel_group_attached = TRUE;
-		}
-	} else {
-		gtk_window_set_decorated(GTK_WINDOW(env->win), FALSE);
-		if (popup_menu_accel_group_attached) {
-			gtk_window_remove_accel_group(GTK_WINDOW(env->win), popup_menu_accel_group);
-			popup_menu_accel_group_attached = FALSE;
-		}
-	}
-	/* Clock */
-	if (prm->clock == 'l')
-		gtk_box_reorder_child(GTK_BOX(main_hbox), vbox_clock, 0);
-	else if (prm->clock == 'r')
-		gtk_box_reorder_child(GTK_BOX(main_hbox), vbox_clock, 1);
+	gtk_window_set_title(GTK_WINDOW(env->win), get_win_title_text());
 	/* Whole window transparency */
 	gtk_window_set_opacity(GTK_WINDOW(env->win), prm->win_transparency);
-	/* Window icon in taskbar? */
-	if (prm->icon_in_taskbar == 'y')
+	/* Following code needs to be run
+	* - twice at program startup (ie once after gtk_widget_show_all() has been called)
+	* - whenever some window params have been changed
+	* - not everytime a new feed is loaded. */
+	if (win_params_have_been_changed(prm, 2)) {
+		gtk_window_set_keep_above(GTK_WINDOW(env->win), FALSE);
 		gtk_window_set_skip_taskbar_hint(GTK_WINDOW(env->win), FALSE);
-	else if (prm->icon_in_taskbar == 'n')
-		gtk_window_set_skip_taskbar_hint(GTK_WINDOW(env->win), TRUE);
-	/* Window on all desktops? */
-	if (prm->win_sticky == 'y')
-		gtk_window_stick(GTK_WINDOW(env->win));
-	else if (prm->win_sticky == 'n')
 		gtk_window_unstick(GTK_WINDOW(env->win));
-	/* gtk_window_present() needs to be run
-	 * - twice at program startup (ie once after gtk_widget_show_all() has been called)
-	 * - whenever params have been changed
-	 * - not when a new feed is loaded. */
-	if (params_have_been_changed(prm, 2))
+		/* Win decoration */
+		if (prm->windec == 'y') {
+			gtk_window_set_decorated(GTK_WINDOW(env->win), TRUE);
+			if (!popup_menu_accel_group_attached) {
+				gtk_window_add_accel_group(GTK_WINDOW(env->win), popup_menu_accel_group);
+				popup_menu_accel_group_attached = TRUE;
+			}
+		} else if (prm->windec == 'n') {
+			gtk_window_set_decorated(GTK_WINDOW(env->win), FALSE);
+			if (popup_menu_accel_group_attached) {
+				gtk_window_remove_accel_group(GTK_WINDOW(env->win), popup_menu_accel_group);
+				popup_menu_accel_group_attached = FALSE;
+			}
+		}
+		/* Clock */
+		if (prm->clock == 'l')
+			gtk_box_reorder_child(GTK_BOX(main_hbox), vbox_clock, 0);
+		else if (prm->clock == 'r')
+			gtk_box_reorder_child(GTK_BOX(main_hbox), vbox_clock, 1);
+		/* Move win */
+		gtk_window_move(GTK_WINDOW(env->win), prm->win_x, prm->win_y);
+		/* Window icon in taskbar? */
+		if (prm->icon_in_taskbar == 'y')
+			gtk_window_set_skip_taskbar_hint(GTK_WINDOW(env->win), FALSE);
+		else if (prm->icon_in_taskbar == 'n')
+			gtk_window_set_skip_taskbar_hint(GTK_WINDOW(env->win), TRUE);
+		/* Window on all desktops? */
+		if (prm->win_sticky == 'y')
+			gtk_window_stick(GTK_WINDOW(env->win));
+		else if (prm->win_sticky == 'n')
+			gtk_window_unstick(GTK_WINDOW(env->win));
+		check_main_win_always_on_top();
 		gtk_window_present(GTK_WINDOW(env->win));
-	check_main_win_always_on_top();
+	}
+	while (gtk_events_pending())
+		gtk_main_iteration();
 	return render_exit_status;
 }
 
@@ -936,14 +1053,18 @@ static gint shift2left_callback()
 
 	if (env->suspend_rq)
 		return TRUE;	/* Does nothing - just return */
+	/* Can't remember where this magical -8 little adjustment comes from... */
 	else if ((shift_counter * prm->shift_size < env->surf_width - env->drwa_width - 8) &&\
-			/*!(env->selection_mode == MULTIPLE && env->stream_fully_read) &&\*/
 			!env->reload_rq && !env->compute_rq) {
 		env->suspend_rq = TRUE;
 		/*
 		 * Draw onto ticker area
 		 * (we now use cairo instead of deprecated gdk_draw_ stuff)
 		 */
+		/* Checking first can't hurt */
+		if (env->c_surf == NULL)
+			big_error(SHIFT2LEFT_NULL_CAIRO_IMAGE_SURFACE, 1,
+				"shift2left_callback(): cairo image surface = NULL");
 		/* Double buffering disabled for drawing area so we need this */
 		gdk_window_get_geometry(env->drw_a->window, &(r.x), &(r.y), NULL, NULL, NULL);
 		if (prm->clock == 'l')			/* We must do that but not quite sure why */
@@ -1018,7 +1139,6 @@ static gint shift2left_callback()
 							"Please check your internet connection and/or "
 							"your connection settings\n",
 							CONNECT_FAIL_MAX);
-							/* TODO: improve that */
 							if (gtk_events_pending()) {
 								if (gtk_main_iteration_do(FALSE))
 									break;
@@ -1200,6 +1320,50 @@ static gint swap_win32_logfiles()
 }
 #endif
 
+/* Question at program start-up about new feed list format conversion:
+ * if version == 0.6.2 and feed list exists and feed list backup doesn't
+ * exist, create backup and convert to new format. */
+#define URL_LIST_BAK_FILE	URL_LIST_FILE"-bak"
+static void test_convert_local_feed_list()
+{
+	FILE	*fp1, *fp2;
+	char	*str;
+	size_t	str_size = 8 * 1024;
+
+	if (strncmp(APP_VERSION_NUMBER, "0.6.2", 5) == 0)
+		if (g_file_test(get_datafile_full_name_from_name(URL_LIST_FILE), G_FILE_TEST_EXISTS) &&\
+				!g_file_test(get_datafile_full_name_from_name(URL_LIST_BAK_FILE), G_FILE_TEST_EXISTS))
+			if (question_win(APP_NAME"-"APP_VERSION_NUMBER" uses a new feed list format internally.\n"
+					"Do you wish your local feed list to be checked and eventually converted ?\n"
+					"(Doing this ONCE is strongly RECOMMENDED.)") == YES) {
+				fp1 = open_new_datafile_with_name(URL_LIST_FILE, "rb");
+				fp2 = open_new_datafile_with_name(URL_LIST_BAK_FILE, "wb");
+				str = malloc2(str_size * sizeof(char));
+#ifndef G_OS_WIN32
+				while (getline(&str, &str_size, fp1) != -1)
+#else
+				while (fgets(str, str_size, fp1) != NULL)
+#endif
+					fprintf(fp2, "%s", str);
+				fclose(fp1);
+				fclose(fp2);
+				fp1 = open_new_datafile_with_name(URL_LIST_FILE, "wb");
+				fp2 = open_new_datafile_with_name(URL_LIST_BAK_FILE, "rb");
+#ifndef G_OS_WIN32
+				while (getline(&str, &str_size, fp2) != -1)
+#else
+				while (fgets(str, str_size, fp2) != NULL)
+#endif
+					if (strncmp(str + 1, "http", 4) == 0 || strncmp(str + 1, "file", 4) == 0)
+						fprintf(fp1, "%c   %s", str[0], str + 1);
+					else
+						fprintf(fp1, "%s", str);
+				free2(str);
+				fclose(fp1);
+				fclose(fp2);
+			}
+}
+
 int main(int argc, char *argv[])
 {
 	GdkPixbuf	*pixb = NULL;
@@ -1229,6 +1393,7 @@ int main(int argc, char *argv[])
 	env->screen_w = env->screen_h = env->depth = 0;
 	env->drwa_width = env->drwa_height = env->surf_width = env->surf_height = 0;
 	env->active_link[0] = '\0';
+	env->mouse_x_in_drwa = -1;
 	env->suspend_rq = env->compute_rq = env->reload_rq = env->stream_fully_read = FALSE;
 	/* env->selection_mode: default = MULTIPLE, set to SINGLE internally if
 	 * selection is unavalaible/empty or after picking a single feed. */
@@ -1332,6 +1497,7 @@ int main(int argc, char *argv[])
 	resrc->id[0] = '\0';
 	resrc->xml_dump[0] = '\0';
 	resrc->fp = NULL;
+	resrc->fp_extra = NULL;
 	for (i = 0; i < NFEEDLINKANDOFFSETMAX; i++) {
 		resrc->link_and_offset[i].url[0] = '\0';
 		resrc->link_and_offset[i].offset_in_surface = 0;
@@ -1347,6 +1513,13 @@ int main(int argc, char *argv[])
 	else
 		quick_setup(prm);
 
+/* NEW and experimental/unstable */
+#ifdef DOUBLE_LINE_TICKER
+	prm->feed_title = 'n';
+	prm->item_title = 'n';
+	prm->item_description = 'y';
+	prm->clock = 'n';
+#endif
 	n_options = 0;
 	n_resources = 0;
 	if (argc > 1) {
@@ -1380,6 +1553,7 @@ int main(int argc, char *argv[])
 	/*
 	 * Feed list stuff
 	 */
+	test_convert_local_feed_list();
 	if ((i = f_list_load_from_file(&feed_list, NULL)) == OK) {
 		feed_list = f_list_sort(feed_list);
 		feed_list = f_list_first(feed_list);
@@ -1440,6 +1614,7 @@ int main(int argc, char *argv[])
 	g_signal_connect(G_OBJECT(popup_menu), "expose-event", G_CALLBACK(mouse_over_opened_popup_menu), NULL);
 	g_signal_connect(G_OBJECT(popup_menu), "leave-notify-event", G_CALLBACK(mouse_over_opened_popup_menu), NULL);
 	g_signal_connect(G_OBJECT(env->drw_a), "scroll-event", G_CALLBACK(mouse_wheel_scroll_on_drawing_area), NULL);
+	g_signal_connect(G_OBJECT(env->drw_a), "motion-notify-event", G_CALLBACK(track_mouse_position_x), NULL);
 
 	vbox_ticker = gtk_vbox_new(FALSE, 0);	/* vbox_ticker is only used to have a v-centered ticker */
 	gtk_box_pack_start(GTK_BOX(vbox_ticker), GTK_WIDGET(env->drw_a), TRUE, FALSE, 0);
@@ -1448,7 +1623,7 @@ int main(int argc, char *argv[])
 	gtk_box_pack_start(GTK_BOX(vbox_clock), GTK_WIDGET(env->drwa_clock), TRUE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(main_hbox), vbox_clock, FALSE, FALSE, 0);
 	/*
-	 * Create cairo image surface from text file or rss feed & compute stuff to draw window.
+	 * Create cairo image surface from text file or rss feed and compute stuff to draw window.
 	 */
 	compute_surface_and_win();
 
