@@ -30,9 +30,7 @@ void import_params()
 
 	dialog = gtk_file_chooser_dialog_new("Import Preferences", GTK_WINDOW(get_ticker_env()->win),
 			GTK_FILE_CHOOSER_ACTION_OPEN,
-			/* esc_key_pressed() and force_quit_dialog() in ticker_otherwins.c return
-			 * GTK_RESPONSE_CLOSE so we must use it here instead of GTK_RESPONSE_CANCEL */
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CLOSE,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL_CLOSE,
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
@@ -97,9 +95,7 @@ void export_params()
 
 	dialog = gtk_file_chooser_dialog_new("Export Preferences", GTK_WINDOW(get_ticker_env()->win),
 			GTK_FILE_CHOOSER_ACTION_SAVE,
-			/* esc_key_pressed() and force_quit_dialog() in ticker_otherwins.c return
-			 * GTK_RESPONSE_CLOSE so we must use it here instead of GTK_RESPONSE_CANCEL */
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CLOSE,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL_CLOSE,
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
