@@ -18,12 +18,10 @@
 
 #include "tickr.h"
 
-/* The 2 followings funcs always return GTK_RESPONSE_CLOSE, although
- * sometimes GTK_RESPONSE_CANCEL would be more appropriate. */
 gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event_key)
 {
 	if (event_key->keyval == GDK_Escape) {
-		gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CLOSE);
+		gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CANCEL_CLOSE);
 		return TRUE;
 	} else
 		return FALSE;
@@ -31,7 +29,7 @@ gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event_key)
 
 void force_quit_dialog(GtkWidget *dialog2)
 {
-	gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CLOSE);
+	gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CANCEL_CLOSE);
 }
 
 /*
@@ -51,7 +49,7 @@ void open_new_txt_file(Resource *resrc)
 	dialog = gtk_file_chooser_dialog_new(
 			"Text File Picker", GTK_WINDOW(env->win),
 			GTK_FILE_CHOOSER_ACTION_OPEN,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CLOSE,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL_CLOSE,
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
@@ -123,7 +121,7 @@ void help_win()
 	dialog = gtk_dialog_new_with_buttons(
 			"Quick Help", GTK_WINDOW(get_ticker_env()->win),
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+			GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL_CLOSE,
 			NULL);
 
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
@@ -205,7 +203,7 @@ static gint license_win()
 	dialog = gtk_dialog_new_with_buttons(
 			"License", GTK_WINDOW(get_ticker_env()->win),
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+			GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL_CLOSE,
 			NULL);
 
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
@@ -256,7 +254,7 @@ void about_win()
 			NULL);
 
 	license_but = gtk_dialog_add_button(GTK_DIALOG(dialog), "License", GTK_RESPONSE_NONE);
-	close_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+	close_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL_CLOSE);
 	close_but = close_but;	/* to Get rid of one stupid compiler warning */
 
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
@@ -289,7 +287,7 @@ void about_win()
 	gtk_table_attach_defaults(GTK_TABLE(table), label[3], 0, 1, 4, 5);
 
 	gtk_widget_show_all(dialog);
-	while (gtk_dialog_run(GTK_DIALOG(dialog)) != GTK_RESPONSE_CLOSE);
+	while (gtk_dialog_run(GTK_DIALOG(dialog)) != GTK_RESPONSE_CANCEL_CLOSE);
 
 	gtk_widget_destroy(dialog);
 	check_main_win_always_on_top();
@@ -473,10 +471,8 @@ void win_with_spinner(win_with_spinner_mode mode, const char *txt)
 	static GtkWidget	*win;
 	GtkWidget		*hbox, *label;
 #ifndef G_OS_WIN32
-#ifndef WITHOUT_GTK_SPINNER
 	static GtkWidget	*spinner;
 	GtkWidget		*space_label;
-#endif
 #endif
 	if (mode == WIN_WITH_SPINNER_OPEN) {
 		gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
@@ -489,17 +485,13 @@ void win_with_spinner(win_with_spinner_mode mode, const char *txt)
 		hbox = gtk_hbox_new(FALSE, 0);
 		gtk_container_add(GTK_CONTAINER(GTK_WINDOW(win)), hbox);
 #ifndef G_OS_WIN32
-#ifndef WITHOUT_GTK_SPINNER
 		spinner = gtk_spinner_new();
 		space_label = gtk_label_new("    ");
-#endif
 #endif
 		label = gtk_label_new(txt);
 #ifndef G_OS_WIN32
-#ifndef WITHOUT_GTK_SPINNER
 		gtk_container_add(GTK_CONTAINER(GTK_BOX(hbox)), spinner);
 		gtk_container_add(GTK_CONTAINER(GTK_BOX(hbox)), space_label);
-#endif
 #endif
 		gtk_container_add(GTK_CONTAINER(GTK_BOX(hbox)), label);
 		gtk_container_set_border_width(GTK_CONTAINER(GTK_BOX(hbox)), 15);
@@ -509,15 +501,11 @@ void win_with_spinner(win_with_spinner_mode mode, const char *txt)
 		while (gtk_events_pending())
 			gtk_main_iteration();
 #ifndef G_OS_WIN32
-#ifndef WITHOUT_GTK_SPINNER
 		gtk_spinner_start(GTK_SPINNER(spinner));
-#endif
 #endif
 	} else if (mode == WIN_WITH_SPINNER_CLOSE) {
 #ifndef G_OS_WIN32
-#ifndef WITHOUT_GTK_SPINNER
 		gtk_spinner_stop(GTK_SPINNER(spinner));
-#endif
 #endif
 		gtk_widget_destroy(win);
 		check_main_win_always_on_top();
