@@ -82,6 +82,7 @@ void set_default_options(Params *prm)
 	prm->pause_on_mouseover = PAUSEONMOUSEOVER;
 	prm->disable_leftclick = DISABLELEFTCLICK;
 	prm->mouse_wheel_scroll = MOUSEWHEELSCROLL;
+	prm->enable_feed_ordering = ENABLEFEEDORDERING;
 
 	prm->use_authentication = USEAUTHENTICATION;
 	str_n_cpy(prm->user, USER, USER_MAXLEN);
@@ -407,6 +408,12 @@ int get_name_value_from_option(Params *prm, const char *option)
 			exit_status = OPTION_VALUE_INVALID;
 		} else
 			prm->mouse_wheel_scroll = value[0];
+	} else if (strcmp(name, "enablefeedordering") == 0) {
+		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
+			fprintf(STD_ERR, "Invalid value: %s\n", option);
+			exit_status = OPTION_VALUE_INVALID;
+		} else
+			prm->enable_feed_ordering = value[0];
 	/* Params in connection settings win */
 	} else if (strcmp(name, "useauth") == 0) {
 		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
@@ -525,6 +532,7 @@ void save_to_config_file(const Params *prm)
 			"-pauseonmouseover=%c\n"
 			"-disableleftclick=%c\n"
 			"-mousewheelscroll=%c\n"
+			"-enablefeedordering=%c\n"
 			"-useauth=%c\n"
 			"-user=%s\n"
 			"-useproxy=%c\n"
@@ -579,6 +587,7 @@ void save_to_config_file(const Params *prm)
 			prm->pause_on_mouseover,
 			prm->disable_leftclick,
 			prm->mouse_wheel_scroll,
+			prm->enable_feed_ordering,
 			prm->use_authentication,
 			prm->user,
 			prm->use_proxy,
