@@ -38,7 +38,7 @@ static GtkWidget	*checkbut_shadow, *checkbut_alwaysontop, *checkbut_windec;
 static GtkWidget	*checkbut_spchars;
 static GtkWidget	*checkbut_feedtitle, *checkbut_itemtitle, *checkbut_itemdes;
 static GtkWidget	*checkbut_striptags, *checkbut_uppercase, *checkbut_nopopups;
-static GtkWidget	*checkbut_mouseover, *checkbut_noleftclick;
+static GtkWidget	*checkbut_mouseover, *checkbut_noleftclick, *checkbut_feedordering;
 static GtkWidget	*font_but, *clock_font_but;
 static GtkWidget	*fg_color_but, *bg_color_but, *clock_fg_color_but, *clock_bg_color_but;
 static GtkWidget	*rbut_box1, *radio_but1_1, *radio_but1_2, *radio_but1_3;
@@ -183,7 +183,7 @@ int modify_params(Params *prm)
 {
 	char		c[2]= "c";
 	gint		response;
-	int		changes_has_been_applied, exit_status = 0, i;
+	int		changes_have_been_applied, exit_status = 0, i;
 	Params		*prm_bak;
 
 	env = get_ticker_env();
@@ -208,9 +208,7 @@ int modify_params(Params *prm)
 		GTK_POLICY_AUTOMATIC);
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), sc_win);
 
-	/* esc_key_pressed() and force_quit_dialog() in ticker_otherwins.c return
-	 * GTK_RESPONSE_CLOSE so we must use it here instead of GTK_RESPONSE_CANCEL. */
-	cancel_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CLOSE);
+	cancel_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL_CLOSE);
 	reset_but = gtk_dialog_add_button(GTK_DIALOG(dialog), "Reset", GTK_RESPONSE_NO);	/* Strange... */
 	/* Having both 'OK' and 'Save' buttons is misleading so we only keep 'OK', which also save settings. */
 	ok_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);
@@ -834,7 +832,6 @@ int modify_params(Params *prm)
 	gtk_box_pack_start(GTK_BOX(rbut_box2), radio_but2_1, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(rbut_box2), radio_but2_2, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(rbut_box2), radio_but2_3, TRUE, TRUE, 0);
-
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_1), TRUE);
 	if (prm->mouse_wheel_scroll == 's')
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_1), TRUE);
@@ -843,6 +840,20 @@ int modify_params(Params *prm)
 	else
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_3), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), rbut_box2, COLUMN2, i, i + 1);
+	i++;
+	/*
+	 * Enable feed re-ordering (by user)
+	 */
+	label[i] = gtk_label_new("Enable feed re-ordering (by user):  ");
+	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
+	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table), label[i], COLUMN1, i, i + 1);
+	checkbut_feedordering = gtk_check_button_new();
+	if (prm->enable_feed_ordering == 'y')
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbut_feedordering), TRUE);
+	else if (prm->enable_feed_ordering == 'n')
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbut_feedordering), FALSE);
+	gtk_table_attach_defaults(GTK_TABLE(table), checkbut_feedordering, COLUMN2, i, i + 1);
 
 	/* Connect buttons / widgets to callbacks */
 	g_signal_connect(G_OBJECT(sysfg_but), "clicked", G_CALLBACK(use_system_fg_color_ticker), NULL);
@@ -857,7 +868,7 @@ int modify_params(Params *prm)
 	/* This  will let us know if changes have been made / applied / must be applied */
 	prm_bak = malloc2(sizeof(Params));
 	memcpy((void *)prm_bak, (const void *)prm, sizeof(Params));
-	changes_has_been_applied = FALSE;
+	changes_have_been_applied = FALSE;
 
 	gtk_widget_show_all(dialog);
 
@@ -1051,18 +1062,28 @@ int modify_params(Params *prm)
 				prm->mouse_wheel_scroll = 'f';
 			else
 				prm->mouse_wheel_scroll = 'n';
+
+			/* Enable feed re-ordering (by user) */
+			if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbut_feedordering)))
+				prm->enable_feed_ordering = 'y';
+			else
+				prm->enable_feed_ordering = 'n';
 		}
 		/* We want a new pixmap so that changes will be effective... now! */
 		if (response == GTK_RESPONSE_APPLY) {	/* Force apply */
 			current_feed();
 			env->reload_rq = TRUE;	/* 'compute_rq' would skip to next pixmap if any */
 			g_timeout_add_full(G_PRIORITY_DEFAULT, 100, update_everything, NULL, NULL);
-			changes_has_been_applied = TRUE;
+			changes_have_been_applied = TRUE;
 			env->suspend_rq = FALSE;
 		} else if (response == GTK_RESPONSE_OK) {
+			if (prm->item_title == 'n' && prm->item_description == 'n')
+				if (question_win("You have unchecked both 'Item title' and 'Item description'.\n"
+						"No much useful information will be displayed. Continue ?") == NO)
+					continue;
 			/* Apply and save when necessary -> OK like that ? */
 			if (memcmp((const void *)prm, (const void *)prm_bak, sizeof(Params)) != 0 || \
-					changes_has_been_applied) {
+					changes_have_been_applied) {
 				current_feed();
 				env->reload_rq = TRUE;
 				g_timeout_add_full(G_PRIORITY_DEFAULT, 100, update_everything, NULL, NULL);
@@ -1072,7 +1093,7 @@ int modify_params(Params *prm)
 		} else {
 			/* Restore and apply when necessary -> OK like that ? */
 			if (memcmp((const void *)prm, (const void *)prm_bak, sizeof(Params)) != 0 || \
-					changes_has_been_applied) {
+					changes_have_been_applied) {
 				memcpy((void *)prm, (const void *)prm_bak, sizeof(Params));
 				current_feed();
 				env->reload_rq = TRUE;
