@@ -157,8 +157,7 @@ void quick_feed_picker(int up_or_down)
 	if (IS_FLIST(flist) && (get_resource()->id)[0] != '\0')
 		if ((f_index = f_list_search(flist, (get_resource()->id))) > -1)
 			highlight_and_go_to_row(tree_view, selection, f_index + 1);
-	while ((response = gtk_dialog_run(GTK_DIALOG(dialog))) != GTK_RESPONSE_CANCEL &&\
-			response != GTK_RESPONSE_CLOSE) {
+	while ((response = gtk_dialog_run(GTK_DIALOG(dialog))) != GTK_RESPONSE_CANCEL_CLOSE) {
 		if (response == GTK_RESPONSE_OK) {
 			if ((f_index = f_list_search(flist, url)) > -1) {
 				set_feed_selection(f_list_nth(flist, f_index + 1));
